@@ -37,7 +37,7 @@ from pygame_menu.widgets.core.widget import AbstractWidgetManager, Widget
 from pygame_menu.widgets.widget.textinput import TextInput
 
 from pygame_menu._types import Union, List, NumberType, Any, Optional, CallbackType, \
-    Literal, Tuple3IntType, NumberInstance, EventVectorType, Callable
+    Tuple3IntType, NumberInstance, EventVectorType, Callable
 
 # Input modes
 COLORINPUT_TYPE_HEX = 'hex'
@@ -49,8 +49,8 @@ COLORINPUT_HEX_FORMAT_NONE = 'none'
 COLORINPUT_HEX_FORMAT_UPPER = 'upper'
 
 # Custom typing
-ColorInputColorType = Literal[COLORINPUT_TYPE_RGB, COLORINPUT_TYPE_HEX]
-ColorInputHexFormatType = Literal[COLORINPUT_HEX_FORMAT_LOWER, COLORINPUT_HEX_FORMAT_UPPER, COLORINPUT_HEX_FORMAT_NONE]
+ColorInputColorType = str
+ColorInputHexFormatType = str
 
 
 # noinspection PyMissingOrEmptyDocstring
