@@ -43,7 +43,7 @@ from pygame_menu.widgets.widget.button import Button
 from pygame_menu.widgets.widget.label import Label
 
 from pygame_menu._types import Optional, NumberType, Dict, Tuple, Union, List, \
-    Vector2NumberType, Literal, Tuple2IntType, NumberInstance, Any, ColorInputType, \
+    Vector2NumberType, Tuple2IntType, NumberInstance, Any, ColorInputType, \
     EventVectorType, PaddingType, CallbackType, ColorInputGradientType, \
     CursorInputType, VectorInstance
 
@@ -56,11 +56,7 @@ S_FINGER_FACTOR = 0.25, 0.25
 
 # Types
 FrameTitleBackgroundColorType = Optional[Union[ColorInputType, ColorInputGradientType, BaseImage]]
-FrameTitleButtonType = Literal[
-    FRAME_TITLE_BUTTON_CLOSE,
-    FRAME_TITLE_BUTTON_MAXIMIZE,
-    FRAME_TITLE_BUTTON_MINIMIZE
-]
+FrameTitleButtonType = str
 
 
 # noinspection PyMissingOrEmptyDocstring,PyProtectedMember
